# Chapter 3: Financial Data Acquisition and Processing

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 3 章：金融数据获取与处理](../../zh/textbook/03_data.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch03_data.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch03_data.py)
  - Extended example: [examples/37_feed_replay_alignment_demo.py](https://github.com/akfamily/akquant/blob/main/examples/37_feed_replay_alignment_demo.py)
  - Guide: [Data Guide](../guide/data.md)
